@@ -1,4 +1,4 @@
-from .mode import BaseMode, register_mode
+from .base_mode import BaseMode, register_mode
 from ..llms.gpt3 import GPT3
 
 @register_mode('raw-codex')
